searchNodes=[{"doc":"This module provides functions that implement some of the Unicode standards: The Unicode Case Folding algorithm to provide case-independent equality checking irrespective of language or script. The Unicode Segmentation algorithm to detect, break or splut strings into grapheme clusters, works and sentences. The Unicode Line Breaking algorithm to determine line breaks (as in word-wrapping).","ref":"Unicode.String.html","title":"Unicode.String","type":"module"},{"doc":"Returns match data indicating if the requested break is applicable at the point between the two string segments represented by {string_before, string_after} . Arguments string is any String.t/0 . options is a keyword list of options. Returns A tuple indicating if a break would be applicable at this point between string_before and string_after . {:break, {string_before, {matched_string, remaining_string}}} or {:no_break, {string_before, {matched_string, remaining_string}}} or {:error, reason} Options :locale is any locale returned by Unicode.String.Segment.known_locales/0 . The default is &quot;root&quot; which corresponds to the break rules defined by the Unicode Segmentation rules. :break is the type of break. It is one of :grapheme , :word , :line or :sentence . The default is :word . :suppressions is a boolean which, if true , will suppress breaks for common abbreviations defined for the locale . The default is true . Examples iex&gt; Unicode.String . break { &quot;This is &quot; , &quot;some words&quot; } { :break , { &quot;This is &quot; , { &quot;s&quot; , &quot;ome words&quot; } } } iex&gt; Unicode.String . break { &quot;This is &quot; , &quot;some words&quot; } , break : :sentence { :no_break , { &quot;This is &quot; , { &quot;s&quot; , &quot;ome words&quot; } } } iex&gt; Unicode.String . break { &quot;This is one. &quot; , &quot;This is some words.&quot; } , break : :sentence { :break , { &quot;This is one. &quot; , { &quot;T&quot; , &quot;his is some words.&quot; } } }","ref":"Unicode.String.html#break/2","title":"Unicode.String.break/2","type":"function"},{"doc":"Returns a boolean indicating if the requested break is applicable at the point between the two string segments represented by {string_before, string_after} . Arguments string is any String.t/0 . options is a keyword list of options. Returns true or false or raises an exception if there is an error Options :locale is any locale returned by Unicode.String.Segment.known_locales/0 . The default is &quot;root&quot; which corresponds to the break rules defined by the Unicode Segmentation rules. :break is the type of break. It is one of :grapheme , :word , :line or :sentence . The default is :word . :suppressions is a boolean which, if true , will suppress breaks for common abbreviations defined for the locale . The default is true . Examples iex&gt; Unicode.String . break? { &quot;This is &quot; , &quot;some words&quot; } true iex&gt; Unicode.String . break? { &quot;This is &quot; , &quot;some words&quot; } , break : :sentence false iex&gt; Unicode.String . break? { &quot;This is one. &quot; , &quot;This is some words.&quot; } , break : :sentence true","ref":"Unicode.String.html#break?/2","title":"Unicode.String.break?/2","type":"function"},{"doc":"Compares two strings in a case insensitive manner. Case folding is applied to the two string arguments which are then compared with the == operator. Arguments string_a and string_b are two strings to be compared type is the case folding type to be applied. The alternatives are :full , :simple and :turkic . The default is :full . Returns true or false Notes This function applies the Unicode Case Folding algorithm The algorithm does not apply any treatment to diacritical marks hence &quot;compare strings without accents&quot; is not part of this function. Examples iex&gt; Unicode.String . equals_ignoring_case? &quot;ABC&quot; , &quot;abc&quot; true iex&gt; Unicode.String . equals_ignoring_case? &quot;beißen&quot; , &quot;beissen&quot; true iex&gt; Unicode.String . equals_ignoring_case? &quot;grüßen&quot; , &quot;grussen&quot; false","ref":"Unicode.String.html#equals_ignoring_case?/3","title":"Unicode.String.equals_ignoring_case?/3","type":"function"},{"doc":"See Unicode.String.Case.Folding.fold/1 .","ref":"Unicode.String.html#fold/1","title":"Unicode.String.fold/1","type":"function"},{"doc":"See Unicode.String.Case.Folding.fold/2 .","ref":"Unicode.String.html#fold/2","title":"Unicode.String.fold/2","type":"function"},{"doc":"Returns next segment in a string. Arguments string is any String.t/0 . options is a keyword list of options. Returns A tuple with the segment and the remainder of the string or &quot;&quot; in case the String reached its end. {next_string, rest_of_the_string} or {:error, reason} Options :locale is any locale returned by Unicode.String.Segment.known_locales/0 . The default is &quot;root&quot; which corresponds to the break rules defined by the Unicode Segmentation rules. :break is the type of break. It is one of :grapheme , :word , :line or :sentence . The default is :word . :suppressions is a boolean which, if true , will suppress breaks for common abbreviations defined for the locale . The default is true . Examples iex&gt; Unicode.String . next &quot;This is a sentence. And another.&quot; , break : :word { &quot;This&quot; , &quot; is a sentence. And another.&quot; } iex&gt; Unicode.String . next &quot;This is a sentence. And another.&quot; , break : :sentence { &quot;This is a sentence. &quot; , &quot;And another.&quot; }","ref":"Unicode.String.html#next/2","title":"Unicode.String.next/2","type":"function"},{"doc":"Splits a string according to the specified break type. Arguments string is any String.t/0 . options is a keyword list of options. Returns A list of strings after applying the specified break rules or {:error, reason} Options :locale is any locale returned by Unicode.String.Segment.known_locales/0 . The default is &quot;root&quot; which corresponds to the break rules defined by the Unicode Segmentation rules. :break is the type of break. It is one of :grapheme , :word , :line or :sentence . The default is :word . :suppressions is a boolean which, if true , will suppress breaks for common abbreviations defined for the locale . The default is true . :trim is a boolean indicating if segments the are comprised of only white space are to be excluded from the returned list. The default is false . Examples iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :word [ &quot;This&quot; , &quot; &quot; , &quot;is&quot; , &quot; &quot; , &quot;a&quot; , &quot; &quot; , &quot;sentence&quot; , &quot;.&quot; , &quot; &quot; , &quot;And&quot; , &quot; &quot; , &quot;another&quot; , &quot;.&quot; ] iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :word , trim : true [ &quot;This&quot; , &quot;is&quot; , &quot;a&quot; , &quot;sentence&quot; , &quot;.&quot; , &quot;And&quot; , &quot;another&quot; , &quot;.&quot; ] iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :sentence [ &quot;This is a sentence. &quot; , &quot;And another.&quot; ]","ref":"Unicode.String.html#split/2","title":"Unicode.String.split/2","type":"function"},{"doc":"Returns an enumerable that splits a string on demand. Arguments string is any String.t/0 . options is a keyword list of options. Returns A function that implements the enumerable protocol or {:error, reason} Options :locale is any locale returned by Unicode.String.Segment.known_locales/0 . The default is &quot;root&quot; which corresponds to the break rules defined by the Unicode Segmentation rules. :break is the type of break. It is one of :grapheme , :word , :line or :sentence . The default is :word . :suppressions is a boolean which, if true , will suppress breaks for common abbreviations defined for the locale . The default is true . :trim is a boolean indicating if segments the are comprised of only white space are to be excluded from the returned list. The default is false . Examples iex&gt; enum = Unicode.String . splitter &quot;This is a sentence. And another.&quot; , break : :word , trim : true iex&gt; Enum . take enum , 3 [ &quot;This&quot; , &quot;is&quot; , &quot;a&quot; ]","ref":"Unicode.String.html#splitter/2","title":"Unicode.String.splitter/2","type":"function"},{"doc":"Return a stream that breaks a string into graphemes, words, sentences or line breaks. Arguments string is any String.t/0 . options is a keyword list of options. Returns A stream that is an Enumerable.t/0 that can be used with the functions in the Stream or Enum modules. {:error, reason} Options :locale is any locale returned by Unicode.String.Segment.known_locales/0 . The default is &quot;root&quot; which corresponds to the break rules defined by the Unicode Segmentation rules. :break is the type of break. It is one of :grapheme , :word , :line or :sentence . The default is :word . :suppressions is a boolean which, if true , will suppress breaks for common abbreviations defined for the locale . The default is true . :trim is a boolean indicating if segments the are comprised of only white space are to be excluded from the returned list. The default is false . Examples iex&gt; Enum.to_list Unicode.String.stream(&quot;this is a set of words&quot;, trim: true) [&quot;this&quot;, &quot;is&quot;, &quot;a&quot;, &quot;set&quot;, &quot;of&quot;, &quot;words&quot;] iex&gt; Enum.to_list Unicode.String.stream(&quot;this is a set of words&quot;, break: :sentence, trim: true) [&quot;this is a set of words&quot;]","ref":"Unicode.String.html#stream/2","title":"Unicode.String.stream/2","type":"function"},{"doc":"","ref":"Unicode.String.html#t:break_match/0","title":"Unicode.String.break_match/0","type":"type"},{"doc":"","ref":"Unicode.String.html#t:break_or_no_break/0","title":"Unicode.String.break_or_no_break/0","type":"type"},{"doc":"","ref":"Unicode.String.html#t:break_type/0","title":"Unicode.String.break_type/0","type":"type"},{"doc":"","ref":"Unicode.String.html#t:error_return/0","title":"Unicode.String.error_return/0","type":"type"},{"doc":"","ref":"Unicode.String.html#t:options/0","title":"Unicode.String.options/0","type":"type"},{"doc":"","ref":"Unicode.String.html#t:split_options/0","title":"Unicode.String.split_options/0","type":"type"},{"doc":"","ref":"Unicode.String.html#t:string_interval/0","title":"Unicode.String.string_interval/0","type":"type"},{"doc":"Implements the Unicode break algorithm","ref":"Unicode.String.Break.html","title":"Unicode.String.Break","type":"module"},{"doc":"Implements the Unicode Case Folding algorithm. The intention of case folding is to facilitate case-insensitive string comparisons. It is not intended to be a general purpose transformation. Although case folding does generally use lower case as its normal form, it is not true for all scripts and codepoints. Therefore case folding should not be used as an alternative to String.downcase/1 .","ref":"Unicode.String.Case.Folding.html","title":"Unicode.String.Case.Folding","type":"module"},{"doc":"Case fold a string. Returns a string after applying the Unicode Case Folding algorithm. It is recommended to call Unicode.String.fold/1,2 instead of this function. Arguments string is any String.t() type is one of :full or :simple . The default is :full . mode is either :turkic or nil . The default is nil . Returns The case folded string Notes No normalization is applied to the string on either input or output.","ref":"Unicode.String.Case.Folding.html#fold/1","title":"Unicode.String.Case.Folding.fold/1","type":"function"},{"doc":"","ref":"Unicode.String.Case.Folding.html#fold/2","title":"Unicode.String.Case.Folding.fold/2","type":"function"},{"doc":"Implements the compilation of the Unicode segment rules.","ref":"Unicode.String.Segment.html","title":"Unicode.String.Segment","type":"module"},{"doc":"Returns a list of the ancestor locales of the a given locale. The list includes the given locale.","ref":"Unicode.String.Segment.html#ancestors/1","title":"Unicode.String.Segment.ancestors/1","type":"function"},{"doc":"Compiles a segment rule in the context of a list of variables. The compile rule can then be inserted into a rule set.","ref":"Unicode.String.Segment.html#compile_rule/2","title":"Unicode.String.Segment.compile_rule/2","type":"function"},{"doc":"","ref":"Unicode.String.Segment.html#compile_rules/2","title":"Unicode.String.Segment.compile_rules/2","type":"function"},{"doc":"Evaluates a list of rules against a given string.","ref":"Unicode.String.Segment.html#evaluate_rules/2","title":"Unicode.String.Segment.evaluate_rules/2","type":"function"},{"doc":"","ref":"Unicode.String.Segment.html#expand_variables/2","title":"Unicode.String.Segment.expand_variables/2","type":"function"},{"doc":"Identifies if a codepoint is a valid identifier character","ref":"Unicode.String.Segment.html#is_id_continue/1","title":"Unicode.String.Segment.is_id_continue/1","type":"macro"},{"doc":"Identifies if a codepoint is a valid start of an identifier","ref":"Unicode.String.Segment.html#is_id_start/1","title":"Unicode.String.Segment.is_id_start/1","type":"macro"},{"doc":"Returns a list of the locales known to Unicode.String.Break","ref":"Unicode.String.Segment.html#known_locales/0","title":"Unicode.String.Segment.known_locales/0","type":"function"},{"doc":"Return the rules as defined by CLDR for a given locale and break type.","ref":"Unicode.String.Segment.html#rules/3","title":"Unicode.String.Segment.rules/3","type":"function"},{"doc":"Return the rules as defined by CLDR for a given locale and break type and raises on error.","ref":"Unicode.String.Segment.html#rules!/3","title":"Unicode.String.Segment.rules!/3","type":"function"},{"doc":"Returns a list of the suppressions for a given locale and segment type.","ref":"Unicode.String.Segment.html#suppressions/2","title":"Unicode.String.Segment.suppressions/2","type":"function"},{"doc":"Returns a list of the suppressions for a given locale and segment type and raises on error.","ref":"Unicode.String.Segment.html#suppressions!/2","title":"Unicode.String.Segment.suppressions!/2","type":"function"},{"doc":"Adds functions supporting some string algorithms in the Unicode standard: The Unicode Case Folding algorithm to provide case-independent equality checking irrespective of language or script with Unicode.String.fold/2 and Unicode.String.equals_ignoring_case?/2 The Unicode Segmentation algorithm to detect, break, split or stream strings into grapheme clusters, words, sentences and line break points. The Unicode Line Breaking algorithm to determine line breaks (as in breaks where word-wrapping would be acceptable).","ref":"readme.html","title":"Unicode String","type":"extras"},{"doc":"The Unicode Case Folding algorithm defines how to perform case folding. This allows comparison of strings in a case-insensitive fashion. It does not define the means to compare ignoring diacritical marks (accents). Some examples follow, for details see: Unicode.String.fold/2 Unicode.String.equals_ignoring_case?/3 iex&gt; Unicode.String . equals_ignoring_case? &quot;ABC&quot; , &quot;abc&quot; true iex&gt; Unicode.String . equals_ignoring_case? &quot;beißen&quot; , &quot;beissen&quot; true iex&gt; Unicode.String . equals_ignoring_case? &quot;grüßen&quot; , &quot;grussen&quot; false","ref":"readme.html#casing","title":"Unicode String - Casing","type":"extras"},{"doc":"The Unicode Segmentation annex details the algorithm to be applied with segmenting text (Elixir strings) into words, sentences, graphemes and line breaks. Some examples follow, for details see: Unicode.String.split/2 Unicode.String.break?/2 Unicode.String.break/2 Unicode.String.splitter/2 Unicode.String.next/2 Unicode.String.stream/2 # Split text at a word boundary. iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :word [ &quot;This&quot; , &quot; &quot; , &quot;is&quot; , &quot; &quot; , &quot;a&quot; , &quot; &quot; , &quot;sentence&quot; , &quot;.&quot; , &quot; &quot; , &quot;And&quot; , &quot; &quot; , &quot;another&quot; , &quot;.&quot; ] # Split text at a word boundary but omit any whitespace iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :word , trim : true [ &quot;This&quot; , &quot;is&quot; , &quot;a&quot; , &quot;sentence&quot; , &quot;.&quot; , &quot;And&quot; , &quot;another&quot; , &quot;.&quot; ] # Split text at a sentence boundary. iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :sentence [ &quot;This is a sentence. &quot; , &quot;And another.&quot; ] # By default, common abbreviations are suppressed (ie # the do not cause a break) iex&gt; Unicode.String . split &quot;No, I don&#39;t have a Ph.D. but I don&#39;t think it matters.&quot; , break : :word , trim : true [ &quot;No&quot; , &quot;,&quot; , &quot;I&quot; , &quot;don&#39;t&quot; , &quot;have&quot; , &quot;a&quot; , &quot;Ph.D&quot; , &quot;.&quot; , &quot;but&quot; , &quot;I&quot; , &quot;don&#39;t&quot; , &quot;think&quot; , &quot;it&quot; , &quot;matters&quot; , &quot;.&quot; ] iex&gt; Unicode.String . split &quot;No, I don&#39;t have a Ph.D. but I don&#39;t think it matters.&quot; , break : :sentence , trim : true [ &quot;No, I don&#39;t have a Ph.D. but I don&#39;t think it matters.&quot; ] # Sentence Break suppressions are locale sensitive. iex&gt; Unicode.String.Segment . known_locales [ &quot;de&quot; , &quot;el&quot; , &quot;en&quot; , &quot;en-US&quot; , &quot;en-US-POSIX&quot; , &quot;es&quot; , &quot;fi&quot; , &quot;fr&quot; , &quot;it&quot; , &quot;ja&quot; , &quot;pt&quot; , &quot;root&quot; , &quot;ru&quot; , &quot;sv&quot; , &quot;zh&quot; , &quot;zh-Hant&quot; ] iex&gt; Unicode.String . split &quot;Non, c&#39;est M. Dubois.&quot; , break : :sentence , trim : true , locale : &quot;fr&quot; [ &quot;Non, c&#39;est M. Dubois.&quot; ] # Note that break: :line does NOT mean split the string # at newlines. It splits the string where a line break would be # acceptable. This is very useful for calculating where # to perform word-wrap on some text. iex&gt; Unicode.String . split &quot;This is a sentence. And another.&quot; , break : :line [ &quot;This &quot; , &quot;is &quot; , &quot;a &quot; , &quot;sentence. &quot; , &quot;And &quot; , &quot;another.&quot; ]","ref":"readme.html#segmentation","title":"Unicode String - Segmentation","type":"extras"},{"doc":"Segmentation can also be streamed using Unicode.String.stream/2 . For large strings this may improve memory usage since the intermediate segments will be garbage collected when they fall out of scope. iex&gt; Enum . to_list Unicode.String . stream ( &quot;this is a set of words&quot; , trim : true ) [ &quot;this&quot; , &quot;is&quot; , &quot;a&quot; , &quot;set&quot; , &quot;of&quot; , &quot;words&quot; ] iex&gt; Enum . map Unicode.String . stream ( &quot;this is a set of words&quot; , trim : true ) , ...&gt; fn word -&gt; %{ word : word , length : String . length ( word ) } end [ %{ length : 4 , word : &quot;this&quot; } , %{ length : 2 , word : &quot;is&quot; } , %{ length : 1 , word : &quot;a&quot; } , %{ length : 3 , word : &quot;set&quot; } , %{ length : 2 , word : &quot;of&quot; } , %{ length : 5 , word : &quot;words&quot; } ]","ref":"readme.html#segment-streaming","title":"Unicode String - Segment Streaming","type":"extras"},{"doc":"The package can be installed by adding :unicode_string to your list of dependencies in mix.exs : def deps do [ { :unicode_string , &quot;~&gt; 1.0&quot; } ] end","ref":"readme.html#installation","title":"Unicode String - Installation","type":"extras"},{"doc":"Copyright 2018 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Unicode String v1.2.0 released on March 14th, 2023. For older changelogs please consult the release tag on GitHub Enhancements Adds Unicode.String.stream/2 to support streaming graphemes, words, sentences and line breaks.","ref":"changelog.html#unicode-string-v1-2-0","title":"Changelog - Unicode String v1.2.0","type":"extras"},{"doc":"This is the changelog for Unicode String v1.1.0 released on September 21st, 2022. For older changelogs please consult the release tag on GitHub Enhancements Updates the segmentation supplemental data (including locales) for CLDR. This adds the &quot;sv&quot; and &quot;fi&quot; locale data for sentence break suppressions.","ref":"changelog.html#unicode-string-v1-1-0","title":"Changelog - Unicode String v1.1.0","type":"extras"},{"doc":"This is the changelog for Unicode String v1.0.1 released on September 15th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Woops, the priv/segments directory was not included in the build artifact","ref":"changelog.html#unicode-string-v1-0-1","title":"Changelog - Unicode String v1.0.1","type":"extras"},{"doc":"This is the changelog for Unicode String v1.0.0 released on September 14th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Update to use Unicode 14 release data.","ref":"changelog.html#unicode-string-v1-0-0","title":"Changelog - Unicode String v1.0.0","type":"extras"},{"doc":"This is the changelog for Unicode String v0.3.0 released on October 11th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Correct deps and docs to align with Elixir 1.11 and recent releases of ex_unicode . Unicode String v0.2.0 This is the changelog for Unicode String v0.2.0 released on July 12th, 2020. For older changelogs please consult the release tag on GitHub Enhancements This release implements the Unicode break rules for graphemes, words, lines (word-wrapping) and sentences. Adds Unicode.String.split/2 Adds Unicode.String.break?/2 Adds Unicode.String.break/2 Adds Unicode.String.splitter/2 Adds Unicode.String.next/2 Unicode String v0.1.0 This is the changelog for Unicode String v0.1.0 released on May 17th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Initial release","ref":"changelog.html#unicode-string-v0-3-0","title":"Changelog - Unicode String v0.3.0","type":"extras"}]